@@ -1,6 +1,7 @@
 from typing import IO, Dict, Generator, Generic, List, TypeVar, Union
 
 from scaleapi.batches import Batch, BatchStatus
+from scaleapi.evaluation_tasks import EvaluationTask
 from scaleapi.exceptions import ScaleInvalidRequest
 from scaleapi.files import File
 from scaleapi.projects import Project
@@ -456,7 +457,8 @@ class ScaleClient:
         project: str,
         batch_name: str,
         callback: str = "",
-        instruction_batch: bool = False,
+        calibration_batch: bool = False,
+        self_label_batch: bool = False,
     ) -> Batch:
         """Create a new Batch within a project.
         https://docs.scale.com/reference#batch-creation
@@ -469,10 +471,14 @@ class ScaleClient:
             callback (str, optional):
                 Email to notify, or URL to POST to
                 when a batch is complete.
-            instruction_batch (bool):
+            calibration_batch (bool):
                 Only applicable for self serve projects.
-                Create an instruction batch by setting
-                the instruction_batch flag to true.
+                Create a calibration_batch batch by setting
+                the calibration_batch flag to true.
+            self_label_batch (bool):
+                Only applicable for self serve projects.
+                Create a self_label batch by setting
+                the self_label_batch flag to true.
 
         Returns:
             Batch: Created batch object
@@ -481,7 +487,8 @@ class ScaleClient:
         payload = dict(
             project=project,
             name=batch_name,
-            instruction_batch=instruction_batch,
+            calibration_batch=calibration_batch,
+            self_label_batch=self_label_batch,
             callback=callback,
         )
         batchdata = self.api.post_request(endpoint, body=payload)
@@ -781,3 +788,42 @@ class ScaleClient:
         payload = dict(file_url=file_url, **kwargs)
         filedata = self.api.post_request(endpoint, body=payload)
         return File(filedata, self)
+
+    def create_evaluation_task(
+        self,
+        task_type: TaskType,
+        **kwargs,
+    ) -> EvaluationTask:
+        """This method can only be used for Self-Serve projects.
+        Supported Task Types: [
+            ImageAnnotation,
+            Categorization,
+            TextCollection,
+            NamedEntityRecognition
+        ]
+        Parameters may differ based on the given task_type.
+
+        Args:
+            task_type (TaskType):
+                Task type to be created
+                e.g.. `TaskType.ImageAnnotation`
+            **kwargs:
+                The same set of parameters are expected with
+                create_task function. Additionally with
+                an expected_response and an optional initial_response
+                if you want to make it a review phase evaluation task
+                The expected_response/initial_response should follow
+                the format of any other tasks' response on your project.
+                It's recommended to try a self_label batch to get
+                familiar with the response format.
+                Scale's API documentation.
+                https://docs.scale.com/reference
+
+        Returns:
+            EvaluationTask:
+                Returns created evaluation task.
+        """
+        endpoint = f"evaluation_tasks/{task_type.value}"
+
+        evaluation_task_data = self.api.post_request(endpoint, body=kwargs)
+        return EvaluationTask(evaluation_task_data, self)
